@@ -8,9 +8,11 @@ class TestTSQL(Validator):
     dialect = "tsql"
 
     def test_tsql(self):
-        self.validate_identity(
-            "with x as (select 1) select * from x union select * from x order by 1 limit 0",
+        self.validate_all(
             "WITH x AS (SELECT 1 AS [1]) SELECT TOP 0 * FROM (SELECT * FROM x UNION SELECT * FROM x) AS _l_0 ORDER BY 1",
+            read={
+                "": "WITH x AS (SELECT 1) SELECT * FROM x UNION SELECT * FROM x ORDER BY 1 LIMIT 0",
+            },
         )
 
         # https://learn.microsoft.com/en-us/previous-versions/sql/sql-server-2008-r2/ms187879(v=sql.105)?redirectedfrom=MSDN
@@ -39,6 +41,9 @@ class TestTSQL(Validator):
         self.validate_identity("1 AND true", "1 <> 0 AND (1 = 1)")
         self.validate_identity("CAST(x AS int) OR y", "CAST(x AS INTEGER) <> 0 OR y <> 0")
         self.validate_identity("TRUNCATE TABLE t1 WITH (PARTITIONS(1, 2 TO 5, 10 TO 20, 84))")
+        self.validate_identity(
+            "WITH t1 AS (SELECT 1 AS a), t2 AS (SELECT 1 AS a) SELECT TOP 10 a FROM t1 UNION ALL SELECT TOP 10 a FROM t2"
+        )
         self.validate_identity(
             "SELECT TOP 10 s.RECORDID, n.c.VALUE('(/*:FORM_ROOT/*:SOME_TAG)[1]', 'float') AS SOME_TAG_VALUE FROM source_table.dbo.source_data AS s(nolock) CROSS APPLY FormContent.nodes('/*:FORM_ROOT') AS N(C)"
         )
@@ -54,6 +59,12 @@ class TestTSQL(Validator):
         self.validate_identity(
             "COPY INTO test_1 FROM 'path' WITH (FORMAT_NAME = test, FILE_TYPE = 'CSV', CREDENTIAL = (IDENTITY='Shared Access Signature', SECRET='token'), FIELDTERMINATOR = ';', ROWTERMINATOR = '0X0A', ENCODING = 'UTF8', DATEFORMAT = 'ymd', MAXERRORS = 10, ERRORFILE = 'errorsfolder', IDENTITY_INSERT = 'ON')"
         )
+        self.validate_identity(
+            "WITH t1 AS (SELECT 1 AS a), t2 AS (SELECT 1 AS a) SELECT TOP 10 a FROM t1 UNION ALL SELECT TOP 10 a FROM t2 ORDER BY a DESC"
+        )
+        self.validate_identity(
+            "WITH t1 AS (SELECT 1 AS a), t2 AS (SELECT 1 AS a) SELECT COUNT(*) FROM (SELECT TOP 10 a FROM t1 UNION ALL SELECT TOP 10 a FROM t2 ORDER BY a DESC) AS t"
+        )
         self.validate_identity(
             'SELECT 1 AS "[x]"',
             "SELECT 1 AS [[x]]]",
@@ -68,6 +79,13 @@ class TestTSQL(Validator):
             "SELECT 1 WHERE EXISTS(SELECT 1)",
         )
 
+        self.validate_all(
+            "CREATE TABLE test_table([ID] [BIGINT] NOT NULL,[EffectiveFrom] [DATETIME2] (3) NOT NULL)",
+            write={
+                "spark": "CREATE TABLE test_table (`ID` BIGINT NOT NULL, `EffectiveFrom` TIMESTAMP NOT NULL)",
+                "tsql": "CREATE TABLE test_table ([ID] BIGINT NOT NULL, [EffectiveFrom] DATETIME2(3) NOT NULL)",
+            },
+        )
         self.validate_all(
             "SELECT CONVERT(DATETIME, '2006-04-25T15:50:59.997', 126)",
             write={
@@ -288,42 +306,6 @@ class TestTSQL(Validator):
             "CREATE TABLE [db].[tbl] ([a] INTEGER)",
         )
 
-        # Test VARCHAR without precision conversion to VARCHAR(1)
-        self.validate_identity(
-            "CREATE TABLE t (col VARCHAR)",
-            "CREATE TABLE t (col VARCHAR(1))",
-        )
-
-        # Test VARCHAR with existing precision should remain unchanged
-        self.validate_identity("CREATE TABLE t (col VARCHAR(50))")
-
-        # Test CHAR without precision conversion to CHAR(1)
-        self.validate_identity(
-            "CREATE TABLE t (col CHAR)",
-            "CREATE TABLE t (col CHAR(1))",
-        )
-
-        # Test CHAR with existing precision should remain unchanged
-        self.validate_identity("CREATE TABLE t (col CHAR(10))")
-
-        # Test cross-dialect conversion: non-TSQL VARCHAR -> TSQL VARCHAR(MAX)
-        self.validate_all(
-            "CREATE TABLE t (col VARCHAR(MAX))",
-            read={
-                "postgres": "CREATE TABLE t (col VARCHAR)",
-                "tsql": "CREATE TABLE t (col VARCHAR(MAX))",
-            },
-        )
-
-        # Test cross-dialect conversion: non-TSQL CHAR -> TSQL CHAR(MAX)
-        self.validate_all(
-            "CREATE TABLE t (col CHAR(MAX))",
-            read={
-                "postgres": "CREATE TABLE t (col CHAR)",
-                "tsql": "CREATE TABLE t (col CHAR(MAX))",
-            },
-        )
-
         self.validate_identity("SELECT a = 1", "SELECT 1 AS a").selects[0].assert_is(
             exp.Alias
         ).args["alias"].assert_is(exp.Identifier)
@@ -540,6 +522,19 @@ class TestTSQL(Validator):
             "CREATE PROCEDURE test(@v1 INTEGER = 1, @v2 CHAR(1) = 'c')",
         )
 
+        for order_by in ("", " ORDER BY c"):
+            for json_clause in ("", " NULL ON NULL", " ABSENT ON NULL"):
+                with self.subTest(f"Testing JSON_ARRAYAGG with options: {order_by}, {json_clause}"):
+                    self.validate_identity(f"JSON_ARRAYAGG(c{order_by}{json_clause})")
+
+        self.validate_all(
+            "JSON_ARRAYAGG(c1 ORDER BY c1)",
+            write={
+                "tsql": "JSON_ARRAYAGG(c1 ORDER BY c1)",
+                "postgres": "JSON_AGG(c1 ORDER BY c1 NULLS FIRST)",
+            },
+        )
+
     def test_option(self):
         possible_options = [
             "HASH GROUP",
@@ -1030,6 +1025,9 @@ FOR XML
         self.validate_identity("ALTER TABLE tbl SET (FILESTREAM_ON = 'test')")
         self.validate_identity("ALTER TABLE tbl SET (DATA_DELETION=ON)")
         self.validate_identity("ALTER TABLE tbl SET (DATA_DELETION=OFF)")
+        self.validate_identity(
+            "ALTER TABLE t1 WITH CHECK ADD CONSTRAINT ctr FOREIGN KEY (c1) REFERENCES t2 (c2)"
+        )
         self.validate_identity(
             "ALTER TABLE tbl SET (SYSTEM_VERSIONING=ON(HISTORY_TABLE=db.tbl, DATA_CONSISTENCY_CHECK=OFF, HISTORY_RETENTION_PERIOD=5 DAYS))"
         )
@@ -2296,6 +2294,10 @@ FROM OPENJSON(@json) WITH (
             "GRANT EXECUTE ON TestProc TO User2 AS TesterRole", check_command_warning=True
         )
 
+    def test_revoke(self):
+        self.validate_identity("REVOKE EXECUTE ON TestProc FROM User2")
+        self.validate_identity("REVOKE EXECUTE ON TestProc FROM TesterRole")
+
     def test_parsename(self):
         for i in range(4):
             with self.subTest("Testing PARSENAME <-> SPLIT_PART"):
